@@ -3,7 +3,7 @@ use warnings;
 
 package Test::MethodFixtures;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 use Carp;
 use Hook::LexWrap qw( wrap );
@@ -14,7 +14,7 @@ use base 'Class::Accessor::Fast';
 
 __PACKAGE__->mk_accessors(qw( mode storage _wrapped ));
 
-our $DEFAULT_STORAGE = 'Storage::File';
+our $DEFAULT_STORAGE = 'File';
 our ( $MODE, $STORAGE );
 my %VALID_MODES = (
     playback    => 1,    # default mode
@@ -32,7 +32,7 @@ sub import {
 
 sub new {
     my $class = shift;
-    my %args  = %{ shift() };
+    my %args  = %{ shift() || {} };
 
     my $mode    = delete $args{mode}    || $MODE    || 'playback';
     my $storage = delete $args{storage} || $STORAGE || $DEFAULT_STORAGE;
@@ -106,8 +106,8 @@ sub _compare_versions {
 
 # pass in optional coderef to return list of values to use
 # (for example to stringify objects)
-sub get_key_sub {
-    my ( $self, $value ) = @_;
+sub _get_key_sub {
+    my $value = shift;
 
     return sub {
         my ( $config, @args ) = @_;
@@ -127,7 +127,7 @@ sub mock {
 
     while ( my ( $name, $value ) = splice @_, 0, 2 ) {
 
-        my $get_key = $self->get_key_sub($value);
+        my $get_key = _get_key_sub($value);
 
         my $pre = sub {
 
@@ -135,7 +135,7 @@ sub mock {
 
             return if $mode eq 'record' or $mode eq 'passthrough';
 
-            my @args = @_;    # original arguments method received
+            my @args = @_;    # original arguments that method received
             pop @args;        # currently undef, will be the return value
 
             my $key = $get_key->( { wantarray => wantarray() }, @args );
@@ -237,20 +237,23 @@ More configuration options:
     my $mocker = Test::MethodFixtures->new(
         mode => 'record',    # set locally for this object
 
-        # optionally specify alternative storage
+        # optionally specify alternative storage:
 
         # override default storage directory
         dir => '/path/to/storage',
 
+        # use Test::MethodFixtures::Storage::File class (default)
+        storage => 'File',
+
         # use alternative Test::MethodFixtures::Storage object
         storage => $storage_obj,
 
-        # load alternative Test::MethodFixtures::Storage:: class
-        storage => '+Alt::Storage::Class', 
+        # load alternative Test::MethodFixtures::Storage class
+        storage => '+Alt::Storage::Class',
         # or:
         storage => { '+Alt::Storage::Class' => \%options },
 
-        # without '+' prefix, 'Test::MethodFixtures::' is prepended to name
+        # without '+' prefix, 'Test::MethodFixtures::Storage' is prepended to name
     );
 
     # simple functions and class methods - can store all arguments
@@ -311,8 +314,8 @@ Feedback welcome!
 =head2 new
 
     my $mocker = Test::MethodFixtures->new(
-        {   mode    => 'record',            # override global / ENV
-            storage => '/path/to/storage',  # override default storage directory
+        {   mode => 'record',            # override global / ENV
+            dir  => '/path/to/storage',  # override default storage directory
 
             # or use alternative Test::MethodFixtures::Storage object
             storage => $storage_obj,
@@ -402,7 +405,7 @@ tests are of less value.
 
 =over
 
-=item * 
+=item *
 
 https://www.destroyallsoftware.com/blog/2014/test-isolation-is-about-avoiding-mocks
 
@@ -418,7 +421,7 @@ L<LWP::UserAgent::Mockable>
 
 =item *
 
-L<Memoize>
+L<Test::Mimic>
 
 =back
 
