@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Carp;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 use Carp;
 use Data::Dump qw( dump );
@@ -15,11 +15,16 @@ use base 'Test::MethodFixtures::Storage';
 
 __PACKAGE__->mk_accessors(qw/ dir /);
 
+our $DEFAULT_DIR = 't/.methodfixtures';
+
 sub new {
     my ( $class, $args ) = @_;
 
     $args ||= {};
-    $args->{dir} ||= 't/.methodfixtures';
+    unless ($args->{dir}) {
+        mkdir $DEFAULT_DIR;
+        $args->{dir} = $DEFAULT_DIR;
+    }
 
     croak "Unable to access " . $args->{dir}
         unless -d $args->{dir} && -w $args->{dir};
@@ -36,7 +41,7 @@ sub store {
     # for now only store on disk
     my $storage = path( $self->dir, $method );
     $storage->mkpath;
-    $storage->child( $self->filename($key) )->spew_utf8( dump $args );
+    $storage->child( $self->_filename($key) )->spew_utf8( dump $args );
 
     return $self;
 }
@@ -47,7 +52,7 @@ sub retrieve {
     my $method = $args->{method};
     my $key    = $args->{key};
 
-    my $storage = path( $self->dir, $method )->child( $self->filename($key) );
+    my $storage = path( $self->dir, $method )->child( $self->_filename($key) );
     return unless $storage->is_file;
 
     my $data = eval $storage->slurp_utf8();;
@@ -55,7 +60,7 @@ sub retrieve {
     return $data;
 }
 
-sub filename {
+sub _filename {
     my $self = shift;
     return md5_hex dump shift;
 }
@@ -83,9 +88,22 @@ Subclass of L<Test::MethodFixtures::Storage>. Implements C<store> and C<retrieve
 
 =head1 METHODS
 
+=head2 new
+
+    my $storage = Test::MethodFixtures::Storage::File->new( \%args );
+
+Class method. Constructor.
+
+Will die if the storage directory does not exist and cannot be written to. Will
+create the storage directory if the default (C<<t/.methodfixtures>>) is used.
+
 =head2 store
 
+Object method. Stores to file.
+
 =head2 retrieve
 
+Object method. Retrieves from file. Empty return if not found (i.e. nothing stored).
+
 =cut
 
